# MkDocs Zettelkasten
This is a reference guide and a demo of MkDocs Zettelkasten features. If you are new to [Zettelkasten method](https://en.wikipedia.org/wiki/Zettelkasten), then check [zettelkasten.de - Getting Started](https://zettelkasten.de/posts/overview/).

The purpose of MkDocs is documentation generation. However, Zettelkasten is a method for smartly organizing your notes. I couldn't find any elegant solution to convert my notes from markdown to something pleasant to read and navigate. That is why I built MkDocs Zettelkasten.

The documentation you are reading is created using MkDocs Zettelkasten (yes, I'm eating my own dog food 😊) only to demonstrate its features. If you are writing documentation, don't use MkDocs Zettelkasten. [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/) is better for that.

Ok, you are still here, so your goal is to turn your markdown-based Zettelkasten into a static, nicely looking HTML site packed with features every smart notes taker needs. Let's see how I can help.

> **Note:** This site uses Zettelkasten conventions — pages are named by timestamp IDs (e.g. `20211122194827`) rather than slugs. This is the intended workflow the plugin supports.

## Features
- [Render markdown document as a card](features/20211123212328.md)
- [Print metadata in card's header](features/20211123213357.md)
- [List references in card's footer](features/20211123213414.md)
- [Find backlinks and list them in card's footer](features/20211123214904.md)
- [Smart relative to absolute links conversion](features/20211123215420.md)
- [Insert zettel title as top heading if not done](features/20211123215950.md)
- [Override previous / next page to follow the sequence of Zettelkasten IDs](features/20211123220309.md)
- [Collect links by tag](features/20211123221647.md)

## Quick start
- [Install MkDocs Zettelkasten](20211122194827.md)
- [Run a minimal demo](20211122195311.md)

## Additional information
- [Documents requirements](20211122195910) <!--- File extension omitted to demonstrate that the link will work without it --->
